@@ -11,6 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from datetime import datetime
 from pathlib import Path
 from typing import Optional
 
@@ -37,14 +38,14 @@ def parse_verbose_option(ctx: click.Context, param: click.Parameter, value: Opti
 class LeanCommand(click.Command):
     """A click.Command wrapper with some Lean CLI customization."""
 
-    def __init__(self, requires_cli_project: bool = False, *args, **kwargs):
+    def __init__(self, requires_lean_config: bool = False, *args, **kwargs):
         """Creates a new LeanCommand instance.
 
-        :param requires_cli_project: True if this command needs to be ran in a Lean CLI project, False if not
+        :param requires_lean_config: True if this command requires a Lean config, False if not
         :param args: the args that are passed on to the click.Command constructor
         :param kwargs: the kwargs that are passed on to the click.Command constructor
         """
-        self._requires_cli_project = requires_cli_project
+        self._requires_lean_config = requires_lean_config
 
         super().__init__(*args, **kwargs)
 
@@ -53,14 +54,14 @@ class LeanCommand(click.Command):
         self.context_settings["max_content_width"] = 120
 
     def invoke(self, ctx):
-        if self._requires_cli_project:
+        if self._requires_lean_config:
             try:
                 # This method will throw if the directory cannot be found
                 container.lean_config_manager().get_cli_root_directory()
             except Exception:
-                # Abort with a display-friendly error message if the command needs to be ran inside a Lean CLI project
+                # Abort with a display-friendly error message if the command requires a Lean config
                 raise RuntimeError(
-                    "This command should be executed in a Lean CLI project, run `lean init` in an empty directory to create one or specify the Lean configuration file to use with --lean-config")
+                    "This command requires a Lean configuration file, run `lean init` in an empty directory to create one, or specify the file to use with --lean-config")
 
         result = super().invoke(ctx)
 
@@ -72,24 +73,23 @@ class LeanCommand(click.Command):
     def get_params(self, ctx):
         params = super().get_params(ctx)
 
-        # Add --config option if the commands needs to be ran inside a Lean CLI project
-        if self._requires_cli_project:
-            params += [click.Option(["--lean-config"],
-                                    type=PathParameter(exists=True, file_okay=True, dir_okay=False),
-                                    help=f"The Lean configuration file that should be used (defaults to the nearest {DEFAULT_LEAN_CONFIG_FILE_NAME})",
-                                    expose_value=False,
-                                    is_eager=True,
-                                    callback=parse_config_option)]
+        # Add --lean-config option if the command requires a Lean config
+        if self._requires_lean_config:
+            params.insert(len(params) - 1, click.Option(["--lean-config"],
+                                                        type=PathParameter(exists=True, file_okay=True, dir_okay=False),
+                                                        help=f"The Lean configuration file that should be used (defaults to the nearest {DEFAULT_LEAN_CONFIG_FILE_NAME})",
+                                                        expose_value=False,
+                                                        is_eager=True,
+                                                        callback=parse_config_option))
 
         # Add --verbose option
-        params += [click.Option(["--verbose"],
-                                type=bool,
-                                help="Enable debug logging",
-                                is_flag=True,
-                                default=False,
-                                expose_value=False,
-                                is_eager=True,
-                                callback=parse_verbose_option)]
+        params.insert(len(params) - 1, click.Option(["--verbose"],
+                                                    help="Enable debug logging",
+                                                    is_flag=True,
+                                                    default=False,
+                                                    expose_value=False,
+                                                    is_eager=True,
+                                                    callback=parse_verbose_option))
 
         return params
 
@@ -131,3 +131,18 @@ class PathParameter(click.ParamType):
             self.fail(f"{self._path_type} '{value}' is a directory.", param, ctx)
 
         return path
+
+
+class DateParameter(click.ParamType):
+    """A click parameter which returns datetime.datetime objects and requires yyyyMMdd input."""
+
+    name = "date"
+
+    def get_metavar(self, param: click.Parameter) -> str:
+        return "[yyyyMMdd]"
+
+    def convert(self, value: str, param: click.Parameter, ctx: click.Context) -> datetime:
+        try:
+            return datetime.strptime(value, "%Y%m%d")
+        except ValueError:
+            self.fail(f"'{value}' does not match the yyyyMMdd format.", param, ctx)
