@@ -23,7 +23,7 @@ from lean.container import container
 from lean.models.config import DebuggingMethod
 
 
-@click.command(cls=LeanCommand, requires_cli_project=True)
+@click.command(cls=LeanCommand, requires_lean_config=True)
 @click.argument("project", type=PathParameter(exists=True, file_okay=True, dir_okay=True))
 @click.option("--output",
               type=PathParameter(exists=False, file_okay=False, dir_okay=True),
@@ -48,7 +48,7 @@ def backtest(project: Path, output: Optional[Path], debug: Optional[str], update
 
     \b
     Go to the following url to learn how to debug backtests locally using the Lean CLI:
-    https://github.com/QuantConnect/lean-cli#local-debugging
+    https://www.quantconnect.com/docs/v2/lean-cli/tutorials/backtesting/debugging-local-backtests
     """
     project_manager = container.project_manager()
     algorithm_file = project_manager.find_algorithm_file(Path(project))
