@@ -21,9 +21,11 @@ import requests
 from lean.components.api.account_client import AccountClient
 from lean.components.api.backtest_client import BacktestClient
 from lean.components.api.compile_client import CompileClient
+from lean.components.api.data_client import DataClient
 from lean.components.api.file_client import FileClient
 from lean.components.api.live_client import LiveClient
 from lean.components.api.node_client import NodeClient
+from lean.components.api.optimization_client import OptimizationClient
 from lean.components.api.project_client import ProjectClient
 from lean.components.util.logger import Logger
 from lean.constants import API_BASE_URL
@@ -48,9 +50,11 @@ class APIClient:
         self.accounts = AccountClient(self)
         self.backtests = BacktestClient(self)
         self.compiles = CompileClient(self)
+        self.data = DataClient(self)
         self.files = FileClient(self)
         self.live = LiveClient(self)
         self.nodes = NodeClient(self)
+        self.optimizations = OptimizationClient(self)
         self.projects = ProjectClient(self)
 
     def get(self, endpoint: str, parameters: Dict[str, Any] = {}) -> Any:
@@ -140,4 +144,7 @@ class APIClient:
         if "messages" in data and len(data["messages"]) > 0:
             raise RequestFailedError(response, "\n".join(data["messages"]))
 
+        if "Message" in data:
+            raise RequestFailedError(response, data["Message"])
+
         raise RequestFailedError(response)
