@@ -40,11 +40,11 @@ class DockerManager:
         :param image: the name of the image to pull
         :param tag: the image's tag to pull
         """
-        self._logger.info(f"Pulling {image}:{tag}, this may take a while...")
+        self._logger.info(f"Pulling {image}:{tag}...")
 
         # We cannot really use docker_client.images.pull() here as it doesn't let us log the progress
         # Downloading multiple gigabytes without showing progress does not provide good developer experience
-        # Since the pull command is the same on Windows, Linux and macOS we can safely use a system call
+        # Since the pull command is the same on Windows, macOS and Linux we can safely use a system call
         os.system(f"docker image pull {image}:{tag}")
 
     def run_image(self, image: str, tag: str, **kwargs) -> bool:
@@ -68,6 +68,7 @@ class DockerManager:
         docker_client = self._get_docker_client()
 
         kwargs["detach"] = True
+        kwargs["remove"] = True
         container = docker_client.containers.run(f"{image}:{tag}", None, **kwargs)
 
         # Kill the container on Ctrl+C
@@ -83,11 +84,11 @@ class DockerManager:
         signal.signal(signal.SIGINT, signal_handler)
 
         # container.logs() is blocking, we run it on a separate thread so the SIGINT handler works properly
-        # If we run this code on the current thread, SIGINT won't be triggered on Windows for some reason
+        # If we run this code on the current thread, SIGINT won't be triggered on Windows when Ctrl+C is triggered
         def print_logs() -> None:
             on_run_called = False
 
-            # Capture all logs and print it to stdout if not running in quiet mode
+            # Capture all logs and print it to stdout
             for line in container.logs(stream=True, follow=True):
                 if not on_run_called:
                     on_run()
