@@ -15,18 +15,22 @@ from dependency_injector.containers import DeclarativeContainer
 from dependency_injector.providers import Factory, Singleton
 
 from lean.components.api.api_client import APIClient
+from lean.components.cloud.cloud_project_manager import CloudProjectManager
 from lean.components.cloud.cloud_runner import CloudRunner
+from lean.components.cloud.data_downloader import DataDownloader
 from lean.components.cloud.pull_manager import PullManager
 from lean.components.cloud.push_manager import PushManager
 from lean.components.config.cli_config_manager import CLIConfigManager
 from lean.components.config.lean_config_manager import LeanConfigManager
+from lean.components.config.optimizer_config_manager import OptimizerConfigManager
 from lean.components.config.project_config_manager import ProjectConfigManager
 from lean.components.config.storage import Storage
 from lean.components.docker.csharp_compiler import CSharpCompiler
 from lean.components.docker.docker_manager import DockerManager
 from lean.components.docker.lean_runner import LeanRunner
 from lean.components.util.logger import Logger
-from lean.components.util.optimization_configurer import OptimizationConfigurer
+from lean.components.util.market_hours_database import MarketHoursDatabase
+from lean.components.util.name_generator import NameGenerator
 from lean.components.util.project_manager import ProjectManager
 from lean.components.util.task_manager import TaskManager
 from lean.components.util.update_manager import UpdateManager
@@ -38,6 +42,7 @@ class Container(DeclarativeContainer):
     logger = Singleton(Logger)
 
     task_manager = Singleton(TaskManager, logger=logger)
+    name_generator = Singleton(NameGenerator)
 
     general_storage = Singleton(Storage, file=GENERAL_CONFIG_PATH)
     credentials_storage = Singleton(Storage, file=CREDENTIALS_CONFIG_PATH)
@@ -53,6 +58,8 @@ class Container(DeclarativeContainer):
 
     project_manager = Singleton(ProjectManager, project_config_manager=project_config_manager)
 
+    market_hours_database = Singleton(MarketHoursDatabase, lean_config_manager=lean_config_manager)
+
     api_client = Factory(APIClient,
                          logger=logger,
                          user_id=cli_config_manager.provided.user_id.get_value()(),
@@ -62,19 +69,27 @@ class Container(DeclarativeContainer):
     pull_manager = Singleton(PullManager,
                              logger=logger,
                              api_client=api_client,
+                             project_manager=project_manager,
                              project_config_manager=project_config_manager)
     push_manager = Singleton(PushManager,
                              logger=logger,
                              api_client=api_client,
                              project_manager=project_manager,
                              project_config_manager=project_config_manager)
+    data_downloader = Singleton(DataDownloader,
+                                logger=logger,
+                                api_client=api_client,
+                                lean_config_manager=lean_config_manager,
+                                market_hours_database=market_hours_database)
+    cloud_project_manager = Singleton(CloudProjectManager,
+                                      api_client=api_client,
+                                      project_config_manager=project_config_manager,
+                                      pull_manager=pull_manager,
+                                      push_manager=push_manager)
 
     docker_manager = Singleton(DockerManager, logger=logger)
 
-    csharp_compiler = Singleton(CSharpCompiler,
-                                logger=logger,
-                                lean_config_manager=lean_config_manager,
-                                docker_manager=docker_manager)
+    csharp_compiler = Singleton(CSharpCompiler, logger=logger, docker_manager=docker_manager)
     lean_runner = Singleton(LeanRunner,
                             logger=logger,
                             csharp_compiler=csharp_compiler,
@@ -83,7 +98,7 @@ class Container(DeclarativeContainer):
 
     update_manager = Singleton(UpdateManager, logger=logger, cache_storage=cache_storage, docker_manager=docker_manager)
 
-    optimization_configurer = Singleton(OptimizationConfigurer, logger=logger)
+    optimizer_config_manager = Singleton(OptimizerConfigManager, logger=logger)
 
 
 container = Container()
